Ignore any changes to the submodule working tree, only show committed differences between the HEAD of the submodule
compared to the recorded commit in the superproject.
Only ignore untracked files in the submodule, but show modifications to the submodule working tree as well as differences
between the recorded commit in the superproject and the checked-out commit in the submodule.
No modifications to the submodule are ignored, which shows untracked files, modified files in the submodule worktree as well as
differences between the recorded commit in the superproject and the checked-out commit in the submodule.